@@ -13,13 +13,11 @@
 from otopi import util
 
 from . import dwh_connection
-from . import grafana
 
 
 @util.export
 def createPlugins(context):
     dwh_connection.Plugin(context=context)
-    grafana.Plugin(context=context)
 
 
 # vim: expandtab tabstop=4 shiftwidth=4
